all.Indsm<-function(){
     cat("\n")
     note_for_Indsm_input()
     cat("\n")
     note_for_close_window()
     IndSMMpar<-data.frame(parameter=c("Gender","bw (kg)","Rit","D (mg)","tau (hr)"),value=c(0))
     IndSMMpar<-edit(IndSMMpar)
##     IndSMMpar<-zcheck(IndSMMpar)
     cat("\n")
     note_for_Indsm_conc_input()
     cat("\n")
     note_for_close_window()
     IndSMpar<-data.frame(ts=c(0),conc=c(0))
     IndSMpar<-edit(IndSMpar)
     IndSMpar<-mscheck(IndSMpar)
     cat("\n")
     Ind.sm(length(IndSMpar$ts),IndSMpar$conc,IndSMpar$ts,IndSMMpar[5,2],IndSMMpar[4,2],IndSMMpar[2,2],IndSMMpar[3,2],IndSMMpar[1,2])
     note_for_convergence_plots()
     convergence_plots_sep()
     note_for_Indsm_output()
     show(samplesStats("*"))
     cat("\n") 
     C<-Indcpr(samplesStats("ka"),IndSMMpar[4,2],IndSMMpar[5,2],IndSMMpar[5,2])
     sim<-matrix(C[1 ,1])
     coutput<-data.frame(sim)
     colnames(coutput)<-list("Ctss_pr (mg/L)")
     show(coutput)    
     cat("\n") 
     Ind.more()
}